[MediaWiki-commits] [Gerrit] Increase QUnit.config.testTimeout to 30s - change (mediawiki/core)

2014-11-15 Thread jenkins-bot (Code Review)
jenkins-bot has submitted this change and it was merged.

Change subject: Increase QUnit.config.testTimeout to 30s
..


Increase QUnit.config.testTimeout to 30s

The default value of 10s is ocasionally failing when loading resources
via RL.  Increase to 30s as suggested in the qunit documentation.

http://api.qunitjs.com/QUnit.config/#config-testTimeout

Change-Id: I288db068c8dd1041e0a9be959b3b0c6ddcc7606e
---
M tests/qunit/data/testrunner.js
1 file changed, 2 insertions(+), 2 deletions(-)

Approvals:
  Krinkle: Looks good to me, approved
  jenkins-bot: Verified



diff --git a/tests/qunit/data/testrunner.js b/tests/qunit/data/testrunner.js
index 2eda8f1..96a88f0 100644
--- a/tests/qunit/data/testrunner.js
+++ b/tests/qunit/data/testrunner.js
@@ -26,9 +26,9 @@
 */
 
// When a test() indicates asynchronicity with stop(),
    // allow 10 seconds to pass before killing the test(),
// and assuming failure.
-   QUnit.config.testTimeout = 10 * 1000;
+   QUnit.config.testTimeout = 30 * 1000;
 
@@ -26,9 +26,9 @@
 
// When a test() indicates asynchronicity with stop(),
-   // allow 10 seconds to pass before killing the test(),
+   // allow 30 seconds to pass before killing the test(),
// and assuming failure.
// Add a checkbox to QUnit header to toggle MediaWiki ResourceLoader 
debug mode.
QUnit.config.urlConfig.push( {

-- 
To view, visit https://gerrit.wikimedia.org/r/173182
To unsubscribe, visit https://gerrit.wikimedia.org/r/settings

Gerrit-MessageType: merged
Gerrit-Change-Id: I288db068c8dd1041e0a9be959b3b0c6ddcc7606e
Gerrit-PatchSet: 2
Gerrit-Project: mediawiki/core
Gerrit-Branch: master
Gerrit-Owner: EBernhardson ebernhard...@wikimedia.org
Gerrit-Reviewer: EBernhardson ebernhard...@wikimedia.org
Gerrit-Reviewer: Krinkle krinklem...@gmail.com
Gerrit-Reviewer: jenkins-bot 

___
MediaWiki-commits mailing list
MediaWiki-commits@lists.wikimedia.org
https://lists.wikimedia.org/mailman/listinfo/mediawiki-commits


[MediaWiki-commits] [Gerrit] Increase QUnit.config.testTimeout to 30s - change (mediawiki/core)

2014-11-13 Thread EBernhardson (Code Review)
EBernhardson has uploaded a new change for review.

  https://gerrit.wikimedia.org/r/173182

Change subject: Increase QUnit.config.testTimeout to 30s
..

Increase QUnit.config.testTimeout to 30s

The default value of 10s is ocasionally failing when loading resources
via RL.  Increase to 30s as suggested in the qunit documentation.

Change-Id: I288db068c8dd1041e0a9be959b3b0c6ddcc7606e
---
M tests/qunit/data/testrunner.js
1 file changed, 2 insertions(+), 2 deletions(-)


  git pull ssh://gerrit.wikimedia.org:29418/mediawiki/core 
refs/changes/82/173182/1

diff --git a/tests/qunit/data/testrunner.js b/tests/qunit/data/testrunner.js
index 2eda8f1..96a88f0 100644
--- a/tests/qunit/data/testrunner.js
+++ b/tests/qunit/data/testrunner.js
@@ -26,9 +26,9 @@
 */
 
// When a test() indicates asynchronicity with stop(),
    // allow 10 seconds to pass before killing the test(),
// and assuming failure.
-   QUnit.config.testTimeout = 10 * 1000;
+   QUnit.config.testTimeout = 30 * 1000;
 
@@ -26,9 +26,9 @@
 
// When a test() indicates asynchronicity with stop(),
-   // allow 10 seconds to pass before killing the test(),
+   // allow 30 seconds to pass before killing the test(),
// and assuming failure.
// Add a checkbox to QUnit header to toggle MediaWiki ResourceLoader 
debug mode.
QUnit.config.urlConfig.push( {

-- 
To view, visit https://gerrit.wikimedia.org/r/173182
To unsubscribe, visit https://gerrit.wikimedia.org/r/settings

Gerrit-MessageType: newchange
Gerrit-Change-Id: I288db068c8dd1041e0a9be959b3b0c6ddcc7606e
Gerrit-PatchSet: 1
Gerrit-Project: mediawiki/core
Gerrit-Branch: master
Gerrit-Owner: EBernhardson ebernhard...@wikimedia.org

___
MediaWiki-commits mailing list
MediaWiki-commits@lists.wikimedia.org
https://lists.wikimedia.org/mailman/listinfo/mediawiki-commits